#!/usr/bin/env node

const fileName = './output.wat';
const fs = require('fs');

const values = [
  'piedra', // 0
  'papel',  // 1
  'tijeras' // 2
];

const importArgs = {
  ppt: {
    mas(a, b) {
      if (a === b) {
        return a;
      }
      if (a === 0) {
        return b === 2 ? a : b;
      }
      if (a === 1) {
        return b === 0 ? a : b;
      }
      if (a === 2) {
        return b === 1 ? a : b;
      }
      throw new Error(`Valores inválidos en 'mas': ${a}, ${b}`);
    },
    menos(a, b) {
      if (a === b) {
        return a;
      }
      if (a === 0) {
        return b === 2 ? b : a;
      }
      if (a === 1) {
        return b === 0 ? b : a;
      }
      if (a === 2) {
        return b === 1 ? b : a;
      }
      throw new Error(`Valores inválidos en 'menos': ${a}, ${b}`);
    }
  }
};

async function getInstance() {
  try {
    const fileContent = fs.readFileSync(fileName, 'utf8');
    const wabt = await require('wabt')();
    const wasmModule = wabt.parseWat(fileName, fileContent);
    const buffer = wasmModule.toBinary({}).buffer;
    const module = await WebAssembly.compile(buffer);
    return WebAssembly.instantiate(module, importArgs);
  } catch (error) {
    console.log(error.message);
    process.exit(1);
  }
}

async function main() {
  const instance = await getInstance();

  const inicio = instance.exports.inicio;
  console.log(values[inicio()]);
}

main();
